@@ -39,7 +39,7 @@ SetupDialogPrg::SetupDialogPrg(TQWidget* parent, const char* name)
   //Ignore list handlers
   grabbing = 0;
   gwm = new KWinModule();
-  connect(gwm, SIGNAL(activeWindowChanged(WId)), SLOT(activeWindowChanged(WId)));
+  connect(gwm, TQ_SIGNAL(activeWindowChanged(WId)), TQ_SLOT(activeWindowChanged(WId)));
   gwm->blockSignals(true);
   in = ignoreBox->lineEdit();
   // Remove useless buttons from widget
@@ -62,7 +62,7 @@ SetupDialogPrg::SetupDialogPrg(TQWidget* parent, const char* name)
   appdlg->terminal->setChecked(false);
   appdlg->tclose->setChecked(false);
   appdlg->tclose->setEnabled(false);
-  connect(appdlg, SIGNAL(apply()), SLOT(appRestart()));
+  connect(appdlg, TQ_SIGNAL(apply()), TQ_SLOT(appRestart()));
    
   // Load the theme List
   TDEStandardDirs sys;
@@ -551,7 +551,7 @@ void SetupDialogPrg::applist_contextMenuRequested(TQIconViewItem* e,const TQPoin
  
     fileName = e->text();
     oldPos = e->index();
-    connect(setpos, SIGNAL(activated(int)), this, SLOT(setnewpos(int)));
+    connect(setpos, TQ_SIGNAL(activated(int)), this, TQ_SLOT(setnewpos(int)));
             
     // Load desktop data
     KSimpleConfig* desktopfile;
@@ -576,8 +576,8 @@ void SetupDialogPrg::applist_contextMenuRequested(TQIconViewItem* e,const TQPoin
       
     popup->insertTitle(e->text());
     popup->insertItem(i18n("Swap with"), setpos);
-    popup->insertItem(i18n("&Edit item"), this, SLOT(editItem()));
-    popup->insertItem(i18n("Remove"), this, SLOT(removeLauncher()));
+    popup->insertItem(i18n("&Edit item"), this, TQ_SLOT(editItem()));
+    popup->insertItem(i18n("Remove"), this, TQ_SLOT(removeLauncher()));
     popup->exec(TQCursor::pos());
     if (popup) {
       delete popup;
